@@ -16,6 +16,9 @@
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 import errno
 import logging
@@ -57,7 +60,7 @@ class Lock(object):
         steal: If True then we remove any existing lock even if it is
                owned by a living process.
         '''
-        if timeout == None:
+        if timeout is None:
             timeout = self.default_timeout
         start_time = time.time()
         while True:
@@ -72,27 +75,37 @@ class Lock(object):
         '''This is the lock implementation used by lock() that has the timeout
         handling.'''
         locker = '%s:%d' % (self.hostname, os.getpid())
+        test_res = self.testlock()
+        if test_res:
+            if steal:
+                os.unlink(self.pathname)
+            elif test_res == (self.hostname, os.getpid()):
+                raise AlreadyLockedError('We already have the lock (pid: %s): %s'
+                                         % (os.getpid(), self.pathname))
+            else:
+                raise AlreadyLockedError('Already locked (pid: %s): %s' %
+                                         (os.getpid(), self.pathname))
+        self.log.debug('Locking: {0} {1}'.format(locker, self.pathname))
         try:
-            test_res = self.testlock()
-            if test_res:
-                if steal:
-                    os.unlink(self.pathname)
-                elif test_res == (self.hostname, os.getpid()):
-                    raise LockError('We already have the locked (pid: %s): %s'
-                            % (os.getpid(), self.pathname))
-                else:
-                    raise AlreadyLockedError('Already locked (pid: %s): %s' %
-                            (os.getpid(), self.pathname))
-            self.log.debug('Locking: {0} {1}'.format(locker, self.pathname))
             return os.symlink(locker, self.pathname)
         except OSError as err:
-            raise LockError('Failed to create lock: %s' % self.pathname, err)
+            # did someone just create the lock?
+            test_res = self.testlock()
+            if test_res:
+                if test_res == (self.hostname, os.getpid()):
+                    raise AlreadyLockedError('"We" just created the lock (pid: %s): %s'
+                                             % (os.getpid(), self.pathname))
+                else:
+                    raise AlreadyLockedError('Someone just created the lock (pid: %s): %s' %
+                                             (os.getpid(), self.pathname))
+            else:
+                raise LockError('Failed to create lock: %s' % self.pathname, err)
 
     def release(self):
         if self.has_lock():
             self.log.debug('Unlocking: {0}'.format(self.pathname))
             os.unlink(self.pathname)
-        elif self.testlock() == None:
+        elif self.testlock() is None:
             raise LockError('Tried to release non existing.')
         else:
             raise LockError('Tried to release someone elses lock.')
@@ -160,7 +173,7 @@ class IDLock(object):
         timeout: in seconds, may be a float, use 0 to only try once.
                  If None, use the sel.default_timeout.
         '''
-        if timeout == None:
+        if timeout is None:
             timeout = self.default_timeout
         start_time = time.time()
         while True:
@@ -196,7 +209,7 @@ class IDLock(object):
                 self.locks.remove(id)
             else:
                 raise LockError(
-                        'Tried to release non existing lock: {0}'.format(id))
+                    'Tried to release non existing lock: {0}'.format(id))
 
 
 class LockError(Exception):
