@@ -143,15 +143,19 @@ def test_watch_files_callback():
             cb_res['path'] = path
             cb_res['reason'] = reason
 
+        shutdown_event = threading.Event()
+
         def watcher():
             watch_files_callback((fn1,), callback, delay=10,
-                                 trigger_on_first_check=True, propagate_callback_errors=False)
+                                 trigger_on_first_check=True, propagate_callback_errors=False,
+                                 shutdown_event=shutdown_event)
         thr = threading.Thread(target=watcher)
         thr.daemon = True
         thr.start()
         time.sleep(0.01)
         eq_(cb_res['path'], fn1)
         eq_(cb_res['reason'], 'INITIAL')
+        shutdown_event.set()  # will stop the thread
 
 
 def test_watch_files_callback_error1():
@@ -166,10 +170,13 @@ def test_watch_files_callback_error1():
             cb_res['reason'] = reason
             raise Exception('Testing error handling')
 
+        shutdown_event = threading.Event()
+
         def watcher():
             try:
                 watch_files_callback((fn1,), callback, delay=10, trigger_on_first_check=True,
-                                     propagate_callback_errors=True)
+                                     propagate_callback_errors=True,
+                                     shutdown_event=shutdown_event)
             except Exception as e:
                 cb_res['exc'] = e
         thr = threading.Thread(target=watcher)
@@ -179,6 +186,7 @@ def test_watch_files_callback_error1():
         eq_(cb_res['path'], fn1)
         eq_(cb_res['reason'], 'INITIAL')
         eq_(str(cb_res['exc']), 'Testing error handling')
+        shutdown_event.set()  # will stop the thread
 
 
 def test_watch_files_callback_error2():
@@ -193,9 +201,12 @@ def test_watch_files_callback_error2():
             cb_res['reason'] = reason
             raise Exception('Testing error handling')
 
+        shutdown_event = threading.Event()
+
         def watcher():
             watch_files_callback((fn1,), callback, delay=10, trigger_on_first_check=True,
-                                 propagate_callback_errors=False)
+                                 propagate_callback_errors=False,
+                                 shutdown_event=shutdown_event)
         thr = threading.Thread(target=watcher)
         thr.daemon = True
         thr.start()
@@ -203,3 +214,4 @@ def test_watch_files_callback_error2():
         eq_(cb_res['path'], fn1)
         eq_(cb_res['reason'], 'INITIAL')
         eq_(cb_res['exc'], None)  # it was only logged
+        shutdown_event.set()  # will stop the thread
