@@ -15,11 +15,14 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-from hcs_utils.storage import Storage, json_load_storage, \
-        json_loads_storage, json_dumps_storage, unicode_storage, \
-        storageify, unstorageify
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+from hcs_utils.storage import Storage, json_loads_storage, json_dumps_storage, unicode_storage, storageify, unstorageify
 from hcs_utils.unittest import eq_
 from pytest import raises
+import six
 
 
 def test_init_empty():
@@ -32,7 +35,7 @@ def test_init_kwargs():
     di1 = {'a': 1, 'b': 2}
     sto = Storage(a=1, b=2)
     eq_(sto.get_dict(), di1)
-    eq_(list(sto), ['a', 'b'])
+    eq_(set(sto), set(['a', 'b']))
 
 
 def test_init_dict():
@@ -151,7 +154,9 @@ def test_repr():
     sto = Storage(a=1, b=2)
     eq_(repr(sto), "Storage(a=1, b=2)")
     sto = Storage(default_factory=list, a=1, b=2)
-    eq_(repr(sto), "Storage(default_factory=<type 'list'>, a=1, b=2)")
+    # class is for python 3
+    assert repr(sto) == "Storage(default_factory=<type 'list'>, a=1, b=2)" or \
+        repr(sto) == "Storage(default_factory=<class 'list'>, a=1, b=2)"
 
 
 def test_json_loads_storage():
@@ -209,8 +214,7 @@ def test_normalize():
 
 
 def test_normalize_case_insensitive():
-    sto = Storage(case_insensitive=True,
-            normalize=lambda key: key.replace(':', '_colon_'))
+    sto = Storage(case_insensitive=True, normalize=lambda key: key.replace(':', '_colon_'))
     sto['a:B'] = 'b'
     eq_(sto.A_coLon_B, 'b')
     eq_(sto['a:b'], 'b')
@@ -218,10 +222,12 @@ def test_normalize_case_insensitive():
 
 
 def test_unicode_storage():
-    sto = Storage(a=1, b=2, c='3', d=u'4')
-    eq_(repr(sto), "Storage(a=1, b=2, c='3', d=u'4')")
+    sto = Storage(a=1, b=2, c=str('3'), d=u'4')
+    expect = "Storage(a=1, b=2, c='3', d='4')" if six.PY3 else "Storage(a=1, b=2, c='3', d=u'4')"
+    eq_(repr(sto), expect)
     sto = unicode_storage(sto)
-    eq_(repr(sto), "Storage(a=u'1', b=u'2', c=u'3', d=u'4')")
+    expect = "Storage(a='1', b='2', c='3', d='4')" if six.PY3 else "Storage(a=u'1', b=u'2', c=u'3', d=u'4')"
+    eq_(repr(sto), expect)
 
 
 def test_denormalize():
@@ -235,14 +241,15 @@ def test_pickle_fix():
     with raises(AttributeError):
         sto.__getattr__('_dict')
 
-storageify_data = [
+storageify_data = \
+    [
         ({}, Storage()),
         ({'a': 4}, Storage(a=4)),
         (
             {'a': 4, 'b': [1, 2, 3, {'b': u'åäö'}]},
             Storage(a=4, b=[1, 2, 3, Storage(b=u'åäö')])
-            ),
-        ]
+        ),
+    ]
 
 
 def test_storageify():
